@@ -2,7 +2,7 @@ import requests
 import json
 
 def create(userID, uploadType, shot, resourceId, filePath, volumeName):
-    url = "sdt-api.qcc.svc.cluster.local"
+    url = "http://sdt-api.qcc.svc.cluster.local"
     url_path = f"{url}/qcc/job"
 
     headers = {
